@@ -385,12 +385,11 @@ def _load_plugins_from_dirs(dirs):
         # This can happen if one plugin imports from another plugin
         if name in sys.modules:
             continue
-        loader = importer.find_module(name)
         # Don't load from pyc files
-        if not loader.filename.endswith('.py'):
+        if not importer.find_module(name).filename.endswith('.py'):
             continue
         try:
-            loaded_module = loader.load_module(name)
+            __import__(name)
         except DependencyError as e:
             if e.has_message():
                 msg = e.message
@@ -408,7 +407,7 @@ def _load_plugins_from_dirs(dirs):
             log.exception(e)
             raise
         else:
-            log.trace('Loaded module %s from %s' % (name, loaded_module.__file__))
+            log.trace('Loaded module %s from %s' % (name, sys.modules[name].__file__))
 
     if _new_phase_queue:
         for phase, args in _new_phase_queue.iteritems():
